from toboso.base import open_database, get_session_manager, get_connection, \
     get_user_database
SITE = 'toboso'
SITE_NAME = 'Toboso Calendar'
SUPPRESS_EMAIL = 1

# Used as the default SMTP sender for mail sent by the site (ie. by
# dulcinea.sendmail.sendmail()), so that any bounces will go to us.
MAIL_SMTP_SENDER = 'webmaster@example.org'
