'''$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/toboso/lib/local_ui.py $
$Id: local_ui.py 23516 2004-02-19 18:32:52Z abenard $
'''

from dulcinea.immutable_list import ImmutableList as _ImmutableList
from dulcinea.ui.user.util import format_user_profile, \
     format_personal_profile_links, format_user_profile_links

from toboso.ui.standard import header, footer

format_login_agreement = lambda : None # No login agreement

FEEDBACK_DOMAIN = 'yourdomain.here'

VALID_FEEDBACK_ADDRESSES = _ImmutableList(['boss'])
